@@ -52,7 +52,7 @@ config_network(){
   configured_ip_no="$(get-all-nic-ip -i | wc -w)"
   while [ "$configured_ip_no" -lt "$eth_port_no" ]; do
     [ -n "$(route -n | grep -E "^0.0.0.0")" ] && config_gw_opt="--ignore-gw"
-    [ -n "$(grep -E "^[[:space:]]*nameserver[[:space:]]+\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b" /etc/resolv.conf)" ] && config_dns_opt="--ignore-dns"
+    [ -n "$(grep -E "^[[:space:]]*nameserver[[:space:]]+\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b" /etc/resolv.conf 2>/dev/null)" ] && config_dns_opt="--ignore-dns"
     # find the configured ports, we will exclude them.
     eth_ports="$(get-nic-devs)"
     configured_port_list=""
@@ -62,9 +62,9 @@ config_network(){
       fi
     done
     if [ -n "$configured_port_list" ]; then
-      ocs-live-netcfg $config_gw_opt $config_dns_opt --ignore-dv "$configured_port_list"
+      ocs-live-netcfg --ip-add " " $config_gw_opt $config_dns_opt --ignore-dv "$configured_port_list"
     else
-      ocs-live-netcfg $config_gw_opt $config_dns_opt
+      ocs-live-netcfg --ip-add " " $config_gw_opt $config_dns_opt
     fi
     configured_ip_no="$(get-all-nic-ip -i | wc -w)"
     [ "$configured_ip_no" -eq "$eth_port_no" ] && break
@@ -149,7 +149,7 @@ case "$switch" in
      . /opt/drbl/setup/files/ocs/live-hook/ocs-live.conf
 
      # run drblpush again so that the network interface can be updated. Maybe there is new ethx.
-     yes "" | drblpush -i -r 1 -z 1 -p $client_no_per_NIC
+     yes "" | drblpush -i -r 1 -z 1 --not-add-start-drbl-srvi -p $client_no_per_NIC
 
      echo "$msg_delimiter_star_line"
      # modify dhcpd.conf, provide IP address to PXE/Etherboot/DRBL client only
